@@ -1,4 +1,3 @@
-
-from nlp_tools.processors.abc_processor import ABCProcessor
 from nlp_tools.processors.class_processor import ClassificationProcessor
 from nlp_tools.processors.sequence_processor import SequenceProcessor
+from nlp_tools.processors.ner_label_processor import NerLabelProcessor
