@@ -160,7 +160,10 @@ class ABCLabelingModel(ABCTaskModel, ABC):
         if optimizer is None:
             optimizer = Adam(learning_rate=1e-5)
         if self.use_rdrop:
-            loss = RDropLoss(loss)
+            if type(loss) == list:
+                loss = [RDropLoss(i) for i in loss]
+            else:
+                loss = RDropLoss(loss)
 
 
         if metrics is None:
