@@ -18,9 +18,6 @@ class BiLSTM_Model(ABCLabelingModel):
                 'rate': 0.4
             },
             'layer_time_distributed': {},
-            'layer_activation': {
-                'activation': 'softmax'
-            }
         }
 
     def build_model_arc(self) -> None:
@@ -33,20 +30,9 @@ class BiLSTM_Model(ABCLabelingModel):
             L.Bidirectional(L.LSTM(**config['layer_blstm']), name='layer_blstm'),
             L.Dropout(**config['layer_dropout'], name='layer_dropout'),
             L.Dense(output_dim, **config['layer_time_distributed']),
-            L.Activation(**config['layer_activation'])
         ]
         tensor = embed_model.output
         for layer in layer_stack:
             tensor = layer(tensor)
 
         self.tf_model = keras.Model(embed_model.inputs, tensor)
-
-
-if __name__ == "__main__":
-    from kashgari.corpus import ChineseDailyNerCorpus
-
-    x, y = ChineseDailyNerCorpus.load_data()
-    x_valid, y_valid = ChineseDailyNerCorpus.load_data('valid')
-    model = BiLSTM_Model()
-    model.fit(x, y, x_valid, y_valid, epochs=2)
-    model.evaluate(*ChineseDailyNerCorpus.load_data('test'))
